import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.match_model_competitor_type import MatchModelCompetitorType
from ..models.match_model_discipline_type_1 import MatchModelDisciplineType1
from ..models.match_model_discipline_type_2_type_1 import MatchModelDisciplineType2Type1
from ..models.match_model_discipline_type_3_type_1 import MatchModelDisciplineType3Type1
from ..models.match_model_fixture_type import MatchModelFixtureType
from ..models.match_model_maximum_period_type_used_type_1 import MatchModelMaximumPeriodTypeUsedType1
from ..models.match_model_maximum_period_type_used_type_2_type_1 import MatchModelMaximumPeriodTypeUsedType2Type1
from ..models.match_model_maximum_period_type_used_type_3_type_1 import MatchModelMaximumPeriodTypeUsedType3Type1
from ..models.match_model_practice_drill_type_type_1 import MatchModelPracticeDrillTypeType1
from ..models.match_model_practice_drill_type_type_2_type_1 import MatchModelPracticeDrillTypeType2Type1
from ..models.match_model_practice_drill_type_type_3_type_1 import MatchModelPracticeDrillTypeType3Type1
from ..models.match_model_status import MatchModelStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.match_model_broadcasts import MatchModelBroadcasts
    from ..models.match_model_environmental_details import MatchModelEnvironmentalDetails
    from ..models.match_model_fixture_profile import MatchModelFixtureProfile
    from ..models.match_model_match_competitor import MatchModelMatchCompetitor
    from ..models.match_model_organization import MatchModelOrganization
    from ..models.match_model_pool import MatchModelPool
    from ..models.match_model_round import MatchModelRound
    from ..models.match_model_season import MatchModelSeason
    from ..models.match_model_series import MatchModelSeries
    from ..models.match_model_social_media import MatchModelSocialMedia
    from ..models.match_model_stage import MatchModelStage
    from ..models.match_model_venue import MatchModelVenue


T = TypeVar("T", bound="MatchModel")


@_attrs_define
class MatchModel:
    """
    Attributes:
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, MatchModelOrganization]): The organization that this match belongs to
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, MatchModelSeason]): The season linked to this record
        practice_drill_type (Union[MatchModelPracticeDrillTypeType1, MatchModelPracticeDrillTypeType2Type1,
            MatchModelPracticeDrillTypeType3Type1, None, Unset]): Practice types
            >- None None
            >- `DRILL` Drill
            >- `FITNESS` Fitness
            >- `GAME` Practice Game
            >- `OTHER` Other
             Example: DRILL.
        international_reference (Union[None, Unset, str]): The international reference for this match given by the sport
            governing body Example: CA3243-3.
        status (Union[Unset, MatchModelStatus]): Match status
            >- `ABANDONED` Abandoned - Match began but had to be stopped
            >- `ABOUT_TO_START` About to Start - Match is about to start
            >- `BYE` Bye - Team has 'rest'
            >- `CANCELLED` Cancelled - Cancelled - will not be played
            >- `CONFIRMED` Confirmed - Match officially completed
            >- `DRAFT` Draft - Not fully scheduled
            >- `FINISHED` Finished - Match finished by not yet 'official'
            >- `IF_NEEDED` If Needed - Only played if needed
            >- `IN_PROGRESS` In Progress - Currently in play
            >- `ON_PITCH` On Pitch - Players appered on the playing field
            >- `PENDING` Pending - Ready to start
            >- `POSTPONED` Postponed - Will be played at a future time
            >- `SCHEDULED` Scheduled - Yet to be played
            >- `WARM_UP` Warm Up - Players have begun to warm up
             Default: MatchModelStatus.SCHEDULED. Example: SCHEDULED.
        fixture_number (Union[None, Unset, int]): Match number (range of -2147483648 to 2147483647) Example: 123.
        name_local (Union[None, Unset, str]): The name of the match in the [local](#section/Introduction/Character-Sets-
            and-Names) language Example: Grand Final.
        name_latin (Union[None, Unset, str]): The name of the match in [latin](#section/Introduction/Character-Sets-and-
            Names) characters Example: Grand Final.
        start_time_local (Union[None, Unset, datetime.datetime]): Local start time Example: 2018-08-16T18:00:00.
        start_time_utc (Union[None, Unset, datetime.datetime]): Start time (UTC). This is automatically generated based
            on the timezone of the venue. Example: 2018-08-16T02:00:00.
        finish_recording_time_utc (Union[Unset, datetime.datetime]): (TO BE REMOVED) Start time (UTC) + durationFull
            Example: 2018-08-16T02:00:00.
        finish_recording_time_local (Union[Unset, datetime.datetime]): (TO BE REMOVED) Start time (Local) + durationFull
            Example: 2018-08-16T02:00:00.
        start_time_actual_utc (Union[None, Unset, datetime.datetime]): Actual start time (UTC) Example:
            2018-08-16T02:02:23.
        end_time_actual_utc (Union[None, Unset, datetime.datetime]): Actual end time (UTC) Example: 2018-08-16T04:02:23.
        times_unconfirmed (Union[Unset, bool]): Is the match time yet to be confirmed ? Example: True.
        locked (Union[Unset, bool]): Is the match locked (to prevent editing)? Example: True.
        placing_if_won (Union[None, Unset, int]): Place if Won? Example: 1.
        placing_if_lost (Union[None, Unset, int]): Place if Lost? Example: 1.
        attendance (Union[None, Unset, int]): Crowd attendance Example: 1123.
        sellout (Union[Unset, bool]): Was the match a sellout? Example: True.
        social (Union['MatchModelSocialMedia', None, Unset]): Social Media contacts
        environmental (Union['MatchModelEnvironmentalDetails', None, Unset]): Details about the environment during the
            fixture
        duration (Union[None, Unset, int]): Length, in minutes, of the match Example: 48.
        duration_full (Union[None, Unset, int]): Full duration including breaks Example: 180.
        ticket_url (Union[None, Unset, str]): Ticket URL
        stage_code (Union[None, Unset, str]): A unique code for the stage. (Unique for season) Example: ST1.
        stage (Union[Unset, MatchModelStage]): The stage that is related to this record
        series_code (Union[None, Unset, str]): A unique code for the season series. (Unique for season) Example: ST1.
        series (Union[Unset, MatchModelSeries]): The season series that is related to this record
        pool_code (Union[None, Unset, str]): A unique code for the pool. (Unique for season) Example: P1.
        pool (Union[Unset, MatchModelPool]): The pool that is related to this record
        round_code (Union[None, Unset, str]): A unique code for the round. (Unique for season) Example: RN1.
        round_ (Union[Unset, MatchModelRound]): The ~ROUND~ that is related to this record
        round_number (Union[None, Unset, str]): The number given to the round Example: 1.
        live_data_available (Union[Unset, bool]): Is live data available? Example: True.
        live_video_available (Union[Unset, bool]): Is live video available ? Example: True.
        fixture_type (Union[Unset, MatchModelFixtureType]): Type of match
            >- `ALL_STAR` All Star
            >- `DEMONSTRATION` Demonstration
            >- `FINAL` Final
            >- `FRIENDLY` Friendly
            >- `PLAYOFF` Playoff
            >- `PRESEASON` Pre Season
            >- `REGULAR` Regular
             Example: REGULAR.
        maximum_period_type_used (Union[MatchModelMaximumPeriodTypeUsedType1, MatchModelMaximumPeriodTypeUsedType2Type1,
            MatchModelMaximumPeriodTypeUsedType3Type1, None, Unset]): Maximum Period Type Used
            >- None None
            >- `EXTRA_TIME` Extra Time
            >- `OVERTIME` Overtime
            >- `REGULAR` Regular
            >- `SHOOTOUT` Shoot-Out
             Example: REGULAR.
        competitor_type (Union[Unset, MatchModelCompetitorType]): The type of competitors in this match
            >- `ENTITY` Entity
            >- `PERSON` Person
             Example: ENTITY.
        competitors (Union[None, Unset, list['MatchModelMatchCompetitor']]): Array of match competitors
        venue_id (Union[None, UUID, Unset]): The unique identifier of the venue Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        venue (Union[Unset, MatchModelVenue]): The venue that this match belongs to
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        profile_id (Union[None, UUID, Unset]): The profile that this match belongs to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture_profile (Union[Unset, MatchModelFixtureProfile]): The profile that this match belongs to
        include_in_standings (Union[Unset, bool]): Include the match in the standings calculation? Default: True.
            Example: True.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        estimated_finish_time_utc (Union[Unset, datetime.datetime]): Estimated end of match
        feature_match (Union[Unset, bool]): Is this match a featured match? Example: True.
        series_fixture_number (Union[None, Unset, int]): The number of the match in a series of matches Example: 1.
        discipline (Union[MatchModelDisciplineType1, MatchModelDisciplineType2Type1, MatchModelDisciplineType3Type1,
            None, Unset]): match discipline
            >- None None
            >- `INDOOR` Indoor
            >- `OUTDOOR` Outdoor
             Example: INDOOR.
        broadcasts (Union[Unset, list[Union['MatchModelBroadcasts', None]]]):
    """

    fixture_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "MatchModelOrganization"] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "MatchModelSeason"] = UNSET
    practice_drill_type: Union[
        MatchModelPracticeDrillTypeType1,
        MatchModelPracticeDrillTypeType2Type1,
        MatchModelPracticeDrillTypeType3Type1,
        None,
        Unset,
    ] = UNSET
    international_reference: Union[None, Unset, str] = UNSET
    status: Union[Unset, MatchModelStatus] = MatchModelStatus.SCHEDULED
    fixture_number: Union[None, Unset, int] = UNSET
    name_local: Union[None, Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    start_time_local: Union[None, Unset, datetime.datetime] = UNSET
    start_time_utc: Union[None, Unset, datetime.datetime] = UNSET
    finish_recording_time_utc: Union[Unset, datetime.datetime] = UNSET
    finish_recording_time_local: Union[Unset, datetime.datetime] = UNSET
    start_time_actual_utc: Union[None, Unset, datetime.datetime] = UNSET
    end_time_actual_utc: Union[None, Unset, datetime.datetime] = UNSET
    times_unconfirmed: Union[Unset, bool] = UNSET
    locked: Union[Unset, bool] = UNSET
    placing_if_won: Union[None, Unset, int] = UNSET
    placing_if_lost: Union[None, Unset, int] = UNSET
    attendance: Union[None, Unset, int] = UNSET
    sellout: Union[Unset, bool] = UNSET
    social: Union["MatchModelSocialMedia", None, Unset] = UNSET
    environmental: Union["MatchModelEnvironmentalDetails", None, Unset] = UNSET
    duration: Union[None, Unset, int] = UNSET
    duration_full: Union[None, Unset, int] = UNSET
    ticket_url: Union[None, Unset, str] = UNSET
    stage_code: Union[None, Unset, str] = UNSET
    stage: Union[Unset, "MatchModelStage"] = UNSET
    series_code: Union[None, Unset, str] = UNSET
    series: Union[Unset, "MatchModelSeries"] = UNSET
    pool_code: Union[None, Unset, str] = UNSET
    pool: Union[Unset, "MatchModelPool"] = UNSET
    round_code: Union[None, Unset, str] = UNSET
    round_: Union[Unset, "MatchModelRound"] = UNSET
    round_number: Union[None, Unset, str] = UNSET
    live_data_available: Union[Unset, bool] = UNSET
    live_video_available: Union[Unset, bool] = UNSET
    fixture_type: Union[Unset, MatchModelFixtureType] = UNSET
    maximum_period_type_used: Union[
        MatchModelMaximumPeriodTypeUsedType1,
        MatchModelMaximumPeriodTypeUsedType2Type1,
        MatchModelMaximumPeriodTypeUsedType3Type1,
        None,
        Unset,
    ] = UNSET
    competitor_type: Union[Unset, MatchModelCompetitorType] = UNSET
    competitors: Union[None, Unset, list["MatchModelMatchCompetitor"]] = UNSET
    venue_id: Union[None, UUID, Unset] = UNSET
    venue: Union[Unset, "MatchModelVenue"] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    profile_id: Union[None, UUID, Unset] = UNSET
    fixture_profile: Union[Unset, "MatchModelFixtureProfile"] = UNSET
    include_in_standings: Union[Unset, bool] = True
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    estimated_finish_time_utc: Union[Unset, datetime.datetime] = UNSET
    feature_match: Union[Unset, bool] = UNSET
    series_fixture_number: Union[None, Unset, int] = UNSET
    discipline: Union[
        MatchModelDisciplineType1, MatchModelDisciplineType2Type1, MatchModelDisciplineType3Type1, None, Unset
    ] = UNSET
    broadcasts: Union[Unset, list[Union["MatchModelBroadcasts", None]]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.match_model_broadcasts import MatchModelBroadcasts
        from ..models.match_model_environmental_details import MatchModelEnvironmentalDetails
        from ..models.match_model_social_media import MatchModelSocialMedia

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        practice_drill_type: Union[None, Unset, str]
        if isinstance(self.practice_drill_type, Unset):
            practice_drill_type = UNSET
        elif isinstance(self.practice_drill_type, MatchModelPracticeDrillTypeType1):
            practice_drill_type = self.practice_drill_type.value
        elif isinstance(self.practice_drill_type, MatchModelPracticeDrillTypeType2Type1):
            practice_drill_type = self.practice_drill_type.value
        elif isinstance(self.practice_drill_type, MatchModelPracticeDrillTypeType3Type1):
            practice_drill_type = self.practice_drill_type.value
        else:
            practice_drill_type = self.practice_drill_type

        international_reference: Union[None, Unset, str]
        if isinstance(self.international_reference, Unset):
            international_reference = UNSET
        else:
            international_reference = self.international_reference

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        fixture_number: Union[None, Unset, int]
        if isinstance(self.fixture_number, Unset):
            fixture_number = UNSET
        else:
            fixture_number = self.fixture_number

        name_local: Union[None, Unset, str]
        if isinstance(self.name_local, Unset):
            name_local = UNSET
        else:
            name_local = self.name_local

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        start_time_local: Union[None, Unset, str]
        if isinstance(self.start_time_local, Unset):
            start_time_local = UNSET
        elif isinstance(self.start_time_local, datetime.datetime):
            start_time_local = self.start_time_local.isoformat()
        else:
            start_time_local = self.start_time_local

        start_time_utc: Union[None, Unset, str]
        if isinstance(self.start_time_utc, Unset):
            start_time_utc = UNSET
        elif isinstance(self.start_time_utc, datetime.datetime):
            start_time_utc = self.start_time_utc.isoformat()
        else:
            start_time_utc = self.start_time_utc

        finish_recording_time_utc: Union[Unset, str] = UNSET
        if not isinstance(self.finish_recording_time_utc, Unset):
            finish_recording_time_utc = self.finish_recording_time_utc.isoformat()

        finish_recording_time_local: Union[Unset, str] = UNSET
        if not isinstance(self.finish_recording_time_local, Unset):
            finish_recording_time_local = self.finish_recording_time_local.isoformat()

        start_time_actual_utc: Union[None, Unset, str]
        if isinstance(self.start_time_actual_utc, Unset):
            start_time_actual_utc = UNSET
        elif isinstance(self.start_time_actual_utc, datetime.datetime):
            start_time_actual_utc = self.start_time_actual_utc.isoformat()
        else:
            start_time_actual_utc = self.start_time_actual_utc

        end_time_actual_utc: Union[None, Unset, str]
        if isinstance(self.end_time_actual_utc, Unset):
            end_time_actual_utc = UNSET
        elif isinstance(self.end_time_actual_utc, datetime.datetime):
            end_time_actual_utc = self.end_time_actual_utc.isoformat()
        else:
            end_time_actual_utc = self.end_time_actual_utc

        times_unconfirmed = self.times_unconfirmed

        locked = self.locked

        placing_if_won: Union[None, Unset, int]
        if isinstance(self.placing_if_won, Unset):
            placing_if_won = UNSET
        else:
            placing_if_won = self.placing_if_won

        placing_if_lost: Union[None, Unset, int]
        if isinstance(self.placing_if_lost, Unset):
            placing_if_lost = UNSET
        else:
            placing_if_lost = self.placing_if_lost

        attendance: Union[None, Unset, int]
        if isinstance(self.attendance, Unset):
            attendance = UNSET
        else:
            attendance = self.attendance

        sellout = self.sellout

        social: Union[None, Unset, dict[str, Any]]
        if isinstance(self.social, Unset):
            social = UNSET
        elif isinstance(self.social, MatchModelSocialMedia):
            social = self.social.to_dict()
        else:
            social = self.social

        environmental: Union[None, Unset, dict[str, Any]]
        if isinstance(self.environmental, Unset):
            environmental = UNSET
        elif isinstance(self.environmental, MatchModelEnvironmentalDetails):
            environmental = self.environmental.to_dict()
        else:
            environmental = self.environmental

        duration: Union[None, Unset, int]
        if isinstance(self.duration, Unset):
            duration = UNSET
        else:
            duration = self.duration

        duration_full: Union[None, Unset, int]
        if isinstance(self.duration_full, Unset):
            duration_full = UNSET
        else:
            duration_full = self.duration_full

        ticket_url: Union[None, Unset, str]
        if isinstance(self.ticket_url, Unset):
            ticket_url = UNSET
        else:
            ticket_url = self.ticket_url

        stage_code: Union[None, Unset, str]
        if isinstance(self.stage_code, Unset):
            stage_code = UNSET
        else:
            stage_code = self.stage_code

        stage: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.stage, Unset):
            stage = self.stage.to_dict()

        series_code: Union[None, Unset, str]
        if isinstance(self.series_code, Unset):
            series_code = UNSET
        else:
            series_code = self.series_code

        series: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.series, Unset):
            series = self.series.to_dict()

        pool_code: Union[None, Unset, str]
        if isinstance(self.pool_code, Unset):
            pool_code = UNSET
        else:
            pool_code = self.pool_code

        pool: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pool, Unset):
            pool = self.pool.to_dict()

        round_code: Union[None, Unset, str]
        if isinstance(self.round_code, Unset):
            round_code = UNSET
        else:
            round_code = self.round_code

        round_: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.round_, Unset):
            round_ = self.round_.to_dict()

        round_number: Union[None, Unset, str]
        if isinstance(self.round_number, Unset):
            round_number = UNSET
        else:
            round_number = self.round_number

        live_data_available = self.live_data_available

        live_video_available = self.live_video_available

        fixture_type: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_type, Unset):
            fixture_type = self.fixture_type.value

        maximum_period_type_used: Union[None, Unset, str]
        if isinstance(self.maximum_period_type_used, Unset):
            maximum_period_type_used = UNSET
        elif isinstance(self.maximum_period_type_used, MatchModelMaximumPeriodTypeUsedType1):
            maximum_period_type_used = self.maximum_period_type_used.value
        elif isinstance(self.maximum_period_type_used, MatchModelMaximumPeriodTypeUsedType2Type1):
            maximum_period_type_used = self.maximum_period_type_used.value
        elif isinstance(self.maximum_period_type_used, MatchModelMaximumPeriodTypeUsedType3Type1):
            maximum_period_type_used = self.maximum_period_type_used.value
        else:
            maximum_period_type_used = self.maximum_period_type_used

        competitor_type: Union[Unset, str] = UNSET
        if not isinstance(self.competitor_type, Unset):
            competitor_type = self.competitor_type.value

        competitors: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.competitors, Unset):
            competitors = UNSET
        elif isinstance(self.competitors, list):
            competitors = []
            for competitors_type_0_item_data in self.competitors:
                competitors_type_0_item = competitors_type_0_item_data.to_dict()
                competitors.append(competitors_type_0_item)

        else:
            competitors = self.competitors

        venue_id: Union[None, Unset, str]
        if isinstance(self.venue_id, Unset):
            venue_id = UNSET
        elif isinstance(self.venue_id, UUID):
            venue_id = str(self.venue_id)
        else:
            venue_id = self.venue_id

        venue: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.venue, Unset):
            venue = self.venue.to_dict()

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        profile_id: Union[None, Unset, str]
        if isinstance(self.profile_id, Unset):
            profile_id = UNSET
        elif isinstance(self.profile_id, UUID):
            profile_id = str(self.profile_id)
        else:
            profile_id = self.profile_id

        fixture_profile: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture_profile, Unset):
            fixture_profile = self.fixture_profile.to_dict()

        include_in_standings = self.include_in_standings

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        estimated_finish_time_utc: Union[Unset, str] = UNSET
        if not isinstance(self.estimated_finish_time_utc, Unset):
            estimated_finish_time_utc = self.estimated_finish_time_utc.isoformat()

        feature_match = self.feature_match

        series_fixture_number: Union[None, Unset, int]
        if isinstance(self.series_fixture_number, Unset):
            series_fixture_number = UNSET
        else:
            series_fixture_number = self.series_fixture_number

        discipline: Union[None, Unset, str]
        if isinstance(self.discipline, Unset):
            discipline = UNSET
        elif isinstance(self.discipline, MatchModelDisciplineType1):
            discipline = self.discipline.value
        elif isinstance(self.discipline, MatchModelDisciplineType2Type1):
            discipline = self.discipline.value
        elif isinstance(self.discipline, MatchModelDisciplineType3Type1):
            discipline = self.discipline.value
        else:
            discipline = self.discipline

        broadcasts: Union[Unset, list[Union[None, dict[str, Any]]]] = UNSET
        if not isinstance(self.broadcasts, Unset):
            broadcasts = []
            for broadcasts_item_data in self.broadcasts:
                broadcasts_item: Union[None, dict[str, Any]]
                if isinstance(broadcasts_item_data, MatchModelBroadcasts):
                    broadcasts_item = broadcasts_item_data.to_dict()
                else:
                    broadcasts_item = broadcasts_item_data
                broadcasts.append(broadcasts_item)

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if practice_drill_type is not UNSET:
            field_dict["practiceDrillType"] = practice_drill_type
        if international_reference is not UNSET:
            field_dict["internationalReference"] = international_reference
        if status is not UNSET:
            field_dict["status"] = status
        if fixture_number is not UNSET:
            field_dict["fixtureNumber"] = fixture_number
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if start_time_local is not UNSET:
            field_dict["startTimeLocal"] = start_time_local
        if start_time_utc is not UNSET:
            field_dict["startTimeUTC"] = start_time_utc
        if finish_recording_time_utc is not UNSET:
            field_dict["finishRecordingTimeUTC"] = finish_recording_time_utc
        if finish_recording_time_local is not UNSET:
            field_dict["finishRecordingTimeLocal"] = finish_recording_time_local
        if start_time_actual_utc is not UNSET:
            field_dict["startTimeActualUTC"] = start_time_actual_utc
        if end_time_actual_utc is not UNSET:
            field_dict["endTimeActualUTC"] = end_time_actual_utc
        if times_unconfirmed is not UNSET:
            field_dict["timesUnconfirmed"] = times_unconfirmed
        if locked is not UNSET:
            field_dict["locked"] = locked
        if placing_if_won is not UNSET:
            field_dict["placingIfWon"] = placing_if_won
        if placing_if_lost is not UNSET:
            field_dict["placingIfLost"] = placing_if_lost
        if attendance is not UNSET:
            field_dict["attendance"] = attendance
        if sellout is not UNSET:
            field_dict["sellout"] = sellout
        if social is not UNSET:
            field_dict["social"] = social
        if environmental is not UNSET:
            field_dict["environmental"] = environmental
        if duration is not UNSET:
            field_dict["duration"] = duration
        if duration_full is not UNSET:
            field_dict["durationFull"] = duration_full
        if ticket_url is not UNSET:
            field_dict["ticketURL"] = ticket_url
        if stage_code is not UNSET:
            field_dict["stageCode"] = stage_code
        if stage is not UNSET:
            field_dict["stage"] = stage
        if series_code is not UNSET:
            field_dict["seriesCode"] = series_code
        if series is not UNSET:
            field_dict["series"] = series
        if pool_code is not UNSET:
            field_dict["poolCode"] = pool_code
        if pool is not UNSET:
            field_dict["pool"] = pool
        if round_code is not UNSET:
            field_dict["roundCode"] = round_code
        if round_ is not UNSET:
            field_dict["round"] = round_
        if round_number is not UNSET:
            field_dict["roundNumber"] = round_number
        if live_data_available is not UNSET:
            field_dict["liveDataAvailable"] = live_data_available
        if live_video_available is not UNSET:
            field_dict["liveVideoAvailable"] = live_video_available
        if fixture_type is not UNSET:
            field_dict["fixtureType"] = fixture_type
        if maximum_period_type_used is not UNSET:
            field_dict["maximumPeriodTypeUsed"] = maximum_period_type_used
        if competitor_type is not UNSET:
            field_dict["competitorType"] = competitor_type
        if competitors is not UNSET:
            field_dict["competitors"] = competitors
        if venue_id is not UNSET:
            field_dict["venueId"] = venue_id
        if venue is not UNSET:
            field_dict["venue"] = venue
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if profile_id is not UNSET:
            field_dict["profileId"] = profile_id
        if fixture_profile is not UNSET:
            field_dict["fixtureProfile"] = fixture_profile
        if include_in_standings is not UNSET:
            field_dict["includeInStandings"] = include_in_standings
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if estimated_finish_time_utc is not UNSET:
            field_dict["estimatedFinishTimeUTC"] = estimated_finish_time_utc
        if feature_match is not UNSET:
            field_dict["featureMatch"] = feature_match
        if series_fixture_number is not UNSET:
            field_dict["seriesFixtureNumber"] = series_fixture_number
        if discipline is not UNSET:
            field_dict["discipline"] = discipline
        if broadcasts is not UNSET:
            field_dict["broadcasts"] = broadcasts

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.match_model_broadcasts import MatchModelBroadcasts
        from ..models.match_model_environmental_details import MatchModelEnvironmentalDetails
        from ..models.match_model_fixture_profile import MatchModelFixtureProfile
        from ..models.match_model_match_competitor import MatchModelMatchCompetitor
        from ..models.match_model_organization import MatchModelOrganization
        from ..models.match_model_pool import MatchModelPool
        from ..models.match_model_round import MatchModelRound
        from ..models.match_model_season import MatchModelSeason
        from ..models.match_model_series import MatchModelSeries
        from ..models.match_model_social_media import MatchModelSocialMedia
        from ..models.match_model_stage import MatchModelStage
        from ..models.match_model_venue import MatchModelVenue

        d = dict(src_dict)
        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, MatchModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = MatchModelOrganization.from_dict(_organization)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, MatchModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = MatchModelSeason.from_dict(_season)

        def _parse_practice_drill_type(
            data: object,
        ) -> Union[
            MatchModelPracticeDrillTypeType1,
            MatchModelPracticeDrillTypeType2Type1,
            MatchModelPracticeDrillTypeType3Type1,
            None,
            Unset,
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                practice_drill_type_type_1 = MatchModelPracticeDrillTypeType1(data)

                return practice_drill_type_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                practice_drill_type_type_2_type_1 = MatchModelPracticeDrillTypeType2Type1(data)

                return practice_drill_type_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                practice_drill_type_type_3_type_1 = MatchModelPracticeDrillTypeType3Type1(data)

                return practice_drill_type_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    MatchModelPracticeDrillTypeType1,
                    MatchModelPracticeDrillTypeType2Type1,
                    MatchModelPracticeDrillTypeType3Type1,
                    None,
                    Unset,
                ],
                data,
            )

        practice_drill_type = _parse_practice_drill_type(d.pop("practiceDrillType", UNSET))

        def _parse_international_reference(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        international_reference = _parse_international_reference(d.pop("internationalReference", UNSET))

        _status = d.pop("status", UNSET)
        status: Union[Unset, MatchModelStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = MatchModelStatus(_status)

        def _parse_fixture_number(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        fixture_number = _parse_fixture_number(d.pop("fixtureNumber", UNSET))

        def _parse_name_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_local = _parse_name_local(d.pop("nameLocal", UNSET))

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        def _parse_start_time_local(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                start_time_local_type_0 = isoparse(data)

                return start_time_local_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        start_time_local = _parse_start_time_local(d.pop("startTimeLocal", UNSET))

        def _parse_start_time_utc(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                start_time_utc_type_0 = isoparse(data)

                return start_time_utc_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        start_time_utc = _parse_start_time_utc(d.pop("startTimeUTC", UNSET))

        _finish_recording_time_utc = d.pop("finishRecordingTimeUTC", UNSET)
        finish_recording_time_utc: Union[Unset, datetime.datetime]
        if isinstance(_finish_recording_time_utc, Unset):
            finish_recording_time_utc = UNSET
        else:
            finish_recording_time_utc = isoparse(_finish_recording_time_utc)

        _finish_recording_time_local = d.pop("finishRecordingTimeLocal", UNSET)
        finish_recording_time_local: Union[Unset, datetime.datetime]
        if isinstance(_finish_recording_time_local, Unset):
            finish_recording_time_local = UNSET
        else:
            finish_recording_time_local = isoparse(_finish_recording_time_local)

        def _parse_start_time_actual_utc(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                start_time_actual_utc_type_0 = isoparse(data)

                return start_time_actual_utc_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        start_time_actual_utc = _parse_start_time_actual_utc(d.pop("startTimeActualUTC", UNSET))

        def _parse_end_time_actual_utc(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                end_time_actual_utc_type_0 = isoparse(data)

                return end_time_actual_utc_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        end_time_actual_utc = _parse_end_time_actual_utc(d.pop("endTimeActualUTC", UNSET))

        times_unconfirmed = d.pop("timesUnconfirmed", UNSET)

        locked = d.pop("locked", UNSET)

        def _parse_placing_if_won(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        placing_if_won = _parse_placing_if_won(d.pop("placingIfWon", UNSET))

        def _parse_placing_if_lost(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        placing_if_lost = _parse_placing_if_lost(d.pop("placingIfLost", UNSET))

        def _parse_attendance(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        attendance = _parse_attendance(d.pop("attendance", UNSET))

        sellout = d.pop("sellout", UNSET)

        def _parse_social(data: object) -> Union["MatchModelSocialMedia", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                social_type_0 = MatchModelSocialMedia.from_dict(data)

                return social_type_0
            except:  # noqa: E722
                pass
            return cast(Union["MatchModelSocialMedia", None, Unset], data)

        social = _parse_social(d.pop("social", UNSET))

        def _parse_environmental(data: object) -> Union["MatchModelEnvironmentalDetails", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                environmental_type_0 = MatchModelEnvironmentalDetails.from_dict(data)

                return environmental_type_0
            except:  # noqa: E722
                pass
            return cast(Union["MatchModelEnvironmentalDetails", None, Unset], data)

        environmental = _parse_environmental(d.pop("environmental", UNSET))

        def _parse_duration(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        duration = _parse_duration(d.pop("duration", UNSET))

        def _parse_duration_full(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        duration_full = _parse_duration_full(d.pop("durationFull", UNSET))

        def _parse_ticket_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        ticket_url = _parse_ticket_url(d.pop("ticketURL", UNSET))

        def _parse_stage_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        stage_code = _parse_stage_code(d.pop("stageCode", UNSET))

        _stage = d.pop("stage", UNSET)
        stage: Union[Unset, MatchModelStage]
        if isinstance(_stage, Unset):
            stage = UNSET
        else:
            stage = MatchModelStage.from_dict(_stage)

        def _parse_series_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        series_code = _parse_series_code(d.pop("seriesCode", UNSET))

        _series = d.pop("series", UNSET)
        series: Union[Unset, MatchModelSeries]
        if isinstance(_series, Unset):
            series = UNSET
        else:
            series = MatchModelSeries.from_dict(_series)

        def _parse_pool_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        pool_code = _parse_pool_code(d.pop("poolCode", UNSET))

        _pool = d.pop("pool", UNSET)
        pool: Union[Unset, MatchModelPool]
        if isinstance(_pool, Unset):
            pool = UNSET
        else:
            pool = MatchModelPool.from_dict(_pool)

        def _parse_round_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        round_code = _parse_round_code(d.pop("roundCode", UNSET))

        _round_ = d.pop("round", UNSET)
        round_: Union[Unset, MatchModelRound]
        if isinstance(_round_, Unset):
            round_ = UNSET
        else:
            round_ = MatchModelRound.from_dict(_round_)

        def _parse_round_number(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        round_number = _parse_round_number(d.pop("roundNumber", UNSET))

        live_data_available = d.pop("liveDataAvailable", UNSET)

        live_video_available = d.pop("liveVideoAvailable", UNSET)

        _fixture_type = d.pop("fixtureType", UNSET)
        fixture_type: Union[Unset, MatchModelFixtureType]
        if isinstance(_fixture_type, Unset):
            fixture_type = UNSET
        else:
            fixture_type = MatchModelFixtureType(_fixture_type)

        def _parse_maximum_period_type_used(
            data: object,
        ) -> Union[
            MatchModelMaximumPeriodTypeUsedType1,
            MatchModelMaximumPeriodTypeUsedType2Type1,
            MatchModelMaximumPeriodTypeUsedType3Type1,
            None,
            Unset,
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                maximum_period_type_used_type_1 = MatchModelMaximumPeriodTypeUsedType1(data)

                return maximum_period_type_used_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                maximum_period_type_used_type_2_type_1 = MatchModelMaximumPeriodTypeUsedType2Type1(data)

                return maximum_period_type_used_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                maximum_period_type_used_type_3_type_1 = MatchModelMaximumPeriodTypeUsedType3Type1(data)

                return maximum_period_type_used_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    MatchModelMaximumPeriodTypeUsedType1,
                    MatchModelMaximumPeriodTypeUsedType2Type1,
                    MatchModelMaximumPeriodTypeUsedType3Type1,
                    None,
                    Unset,
                ],
                data,
            )

        maximum_period_type_used = _parse_maximum_period_type_used(d.pop("maximumPeriodTypeUsed", UNSET))

        _competitor_type = d.pop("competitorType", UNSET)
        competitor_type: Union[Unset, MatchModelCompetitorType]
        if isinstance(_competitor_type, Unset):
            competitor_type = UNSET
        else:
            competitor_type = MatchModelCompetitorType(_competitor_type)

        def _parse_competitors(data: object) -> Union[None, Unset, list["MatchModelMatchCompetitor"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                competitors_type_0 = []
                _competitors_type_0 = data
                for competitors_type_0_item_data in _competitors_type_0:
                    competitors_type_0_item = MatchModelMatchCompetitor.from_dict(competitors_type_0_item_data)

                    competitors_type_0.append(competitors_type_0_item)

                return competitors_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["MatchModelMatchCompetitor"]], data)

        competitors = _parse_competitors(d.pop("competitors", UNSET))

        def _parse_venue_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                venue_id_type_0 = UUID(data)

                return venue_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        venue_id = _parse_venue_id(d.pop("venueId", UNSET))

        _venue = d.pop("venue", UNSET)
        venue: Union[Unset, MatchModelVenue]
        if isinstance(_venue, Unset):
            venue = UNSET
        else:
            venue = MatchModelVenue.from_dict(_venue)

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        def _parse_profile_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                profile_id_type_0 = UUID(data)

                return profile_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        profile_id = _parse_profile_id(d.pop("profileId", UNSET))

        _fixture_profile = d.pop("fixtureProfile", UNSET)
        fixture_profile: Union[Unset, MatchModelFixtureProfile]
        if isinstance(_fixture_profile, Unset):
            fixture_profile = UNSET
        else:
            fixture_profile = MatchModelFixtureProfile.from_dict(_fixture_profile)

        include_in_standings = d.pop("includeInStandings", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        _estimated_finish_time_utc = d.pop("estimatedFinishTimeUTC", UNSET)
        estimated_finish_time_utc: Union[Unset, datetime.datetime]
        if isinstance(_estimated_finish_time_utc, Unset):
            estimated_finish_time_utc = UNSET
        else:
            estimated_finish_time_utc = isoparse(_estimated_finish_time_utc)

        feature_match = d.pop("featureMatch", UNSET)

        def _parse_series_fixture_number(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        series_fixture_number = _parse_series_fixture_number(d.pop("seriesFixtureNumber", UNSET))

        def _parse_discipline(
            data: object,
        ) -> Union[
            MatchModelDisciplineType1, MatchModelDisciplineType2Type1, MatchModelDisciplineType3Type1, None, Unset
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                discipline_type_1 = MatchModelDisciplineType1(data)

                return discipline_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                discipline_type_2_type_1 = MatchModelDisciplineType2Type1(data)

                return discipline_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                discipline_type_3_type_1 = MatchModelDisciplineType3Type1(data)

                return discipline_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    MatchModelDisciplineType1,
                    MatchModelDisciplineType2Type1,
                    MatchModelDisciplineType3Type1,
                    None,
                    Unset,
                ],
                data,
            )

        discipline = _parse_discipline(d.pop("discipline", UNSET))

        broadcasts = []
        _broadcasts = d.pop("broadcasts", UNSET)
        for broadcasts_item_data in _broadcasts or []:

            def _parse_broadcasts_item(data: object) -> Union["MatchModelBroadcasts", None]:
                if data is None:
                    return data
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    broadcasts_item_type_0 = MatchModelBroadcasts.from_dict(data)

                    return broadcasts_item_type_0
                except:  # noqa: E722
                    pass
                return cast(Union["MatchModelBroadcasts", None], data)

            broadcasts_item = _parse_broadcasts_item(broadcasts_item_data)

            broadcasts.append(broadcasts_item)

        match_model = cls(
            fixture_id=fixture_id,
            organization_id=organization_id,
            organization=organization,
            season_id=season_id,
            season=season,
            practice_drill_type=practice_drill_type,
            international_reference=international_reference,
            status=status,
            fixture_number=fixture_number,
            name_local=name_local,
            name_latin=name_latin,
            start_time_local=start_time_local,
            start_time_utc=start_time_utc,
            finish_recording_time_utc=finish_recording_time_utc,
            finish_recording_time_local=finish_recording_time_local,
            start_time_actual_utc=start_time_actual_utc,
            end_time_actual_utc=end_time_actual_utc,
            times_unconfirmed=times_unconfirmed,
            locked=locked,
            placing_if_won=placing_if_won,
            placing_if_lost=placing_if_lost,
            attendance=attendance,
            sellout=sellout,
            social=social,
            environmental=environmental,
            duration=duration,
            duration_full=duration_full,
            ticket_url=ticket_url,
            stage_code=stage_code,
            stage=stage,
            series_code=series_code,
            series=series,
            pool_code=pool_code,
            pool=pool,
            round_code=round_code,
            round_=round_,
            round_number=round_number,
            live_data_available=live_data_available,
            live_video_available=live_video_available,
            fixture_type=fixture_type,
            maximum_period_type_used=maximum_period_type_used,
            competitor_type=competitor_type,
            competitors=competitors,
            venue_id=venue_id,
            venue=venue,
            external_id=external_id,
            profile_id=profile_id,
            fixture_profile=fixture_profile,
            include_in_standings=include_in_standings,
            updated=updated,
            added=added,
            estimated_finish_time_utc=estimated_finish_time_utc,
            feature_match=feature_match,
            series_fixture_number=series_fixture_number,
            discipline=discipline,
            broadcasts=broadcasts,
        )

        return match_model



from enum import Enum


class SeasonListStandard(str, Enum):
    APPROVED_TEST_MATCHES = "APPROVED_TEST_MATCHES"
    COMMONWEALTH_GAMES = "COMMONWEALTH_GAMES"
    CONTINENTAL_CHAMPIONSHIP = "CONTINENTAL_CHAMPIONSHIP"
    CONTINENTAL_CHAMPIONSHIP_DIV_2 = "CONTINENTAL_CHAMPIONSHIP_DIV_2"
    CONTINENTAL_CHAMPIONSHIP_DIV_3 = "CONTINENTAL_CHAMPIONSHIP_DIV_3"
    CONTINENTAL_CHAMPIONSHIP_DIV_4 = "CONTINENTAL_CHAMPIONSHIP_DIV_4"
    CONTINENTAL_QUALIFIER = "CONTINENTAL_QUALIFIER"
    ELITE = "ELITE"
    FIH_NATIONS_CUP = "FIH_NATIONS_CUP"
    FIH_OLYMPIC_QUALIFIERS = "FIH_OLYMPIC_QUALIFIERS"
    FIH_PRO_LEAGUE = "FIH_PRO_LEAGUE"
    FIH_WORLD_CUP = "FIH_WORLD_CUP"
    FIH_WORLD_CUP_QUALIFIERS = "FIH_WORLD_CUP_QUALIFIERS"
    FRIENDLY = "FRIENDLY"
    GRASS_ROOT = "GRASS_ROOT"
    HISTORICAL_BASELINE = "HISTORICAL_BASELINE"
    HOCKEY_SERIES_OPEN = "HOCKEY_SERIES_OPEN"
    INTERNATIONAL = "INTERNATIONAL"
    INVITATIONAL_TOURNAMENT = "INVITATIONAL_TOURNAMENT"
    NONCONTINENTAL_CHAMPIONSHIP = "NONCONTINENTAL_CHAMPIONSHIP"
    OLYMPIC = "OLYMPIC"
    OLYMPICS = "OLYMPICS"
    REGION = "REGION"
    TIER2 = "TIER2"
    TIER3 = "TIER3"
    WORLD_CHAMPIONSHIP = "WORLD_CHAMPIONSHIP"
    WORLD_LEAGUE = "WORLD_LEAGUE"
    ZONE_CHAMPIONSHIP = "ZONE_CHAMPIONSHIP"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..models.match_profiles_model_match_profile_configuration_match_roles_item import (
    MatchProfilesModelMatchProfileConfigurationMatchRolesItem,
)
from ..models.match_profiles_model_match_profile_configuration_type_of_cards_item import (
    MatchProfilesModelMatchProfileConfigurationTypeOfCardsItem,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="MatchProfilesModelMatchProfileConfiguration")


@_attrs_define
class MatchProfilesModelMatchProfileConfiguration:
    """Match Profile Configuration

    Attributes:
        number_of_periods (Union[Unset, float]): The number of regular periods to play.
        period_length (Union[Unset, float]): The length (in minutes) of a regular period.
        overtime_allowed (Union[Unset, bool]): Is overtime allowed?
        overtime_length (Union[Unset, float]): The length (in minutes) of an overtime period.
        maximum_roster_size (Union[Unset, float]): The maximum number of persons allowed on a roster.
        period_break_duration (Union[Unset, float]): The length (in minutes) of a break between periods.
        half_time_duration (Union[Unset, float]): The length (in minutes) of a half time break.
        maximum_players_on_court (Union[Unset, float]): The maximum number of players on the Court per team.
        maximum_goalkeeper_substitutions (Union[Unset, float]): The maximum number of Goalkeeper substitutions allowed
            per team for a match.
        type_of_cards (Union[Unset, list[MatchProfilesModelMatchProfileConfigurationTypeOfCardsItem]]): The type of
            cards allowed in this match.
        red_card_seconds (Union[Unset, float]): The length (in seconds) a player leaves the field for when issued a red
            card.
        yellow_card_seconds (Union[Unset, float]): The length (in seconds) a player leaves the field for when issued a
            yellow card.
        blue_card_seconds (Union[Unset, float]): The length (in seconds) a player leaves the field for when issued a
            blue card.
        match_roles (Union[Unset, list[MatchProfilesModelMatchProfileConfigurationMatchRolesItem]]): The official roles
            that are assignable for this match.
        bib_numbers_required (Union[Unset, bool]): Are bib numbers required for the match?.
        switch_playing_direction (Union[None, Unset, list[float]]): Switch direction of play after period/s. Example:
            [2].
        shootout_if_tie (Union[Unset, bool]): Is there a shootout if the game ends with a tied score?.
        shots_until_sudden_death (Union[Unset, float]): The number of shots each team takes in the shootout before it
            moves sudden death phase.
        timeouts_allowed (Union[Unset, float]): The number of timeouts a team can use in a match.
        video_review_allowed (Union[Unset, bool]): Is video review allowed?.
        reset_timeouts_after_periods (Union[None, Unset, list[float]]): Reset Timeouts to 0 after period/s. Example: [1,
            2, 3].
    """

    number_of_periods: Union[Unset, float] = UNSET
    period_length: Union[Unset, float] = UNSET
    overtime_allowed: Union[Unset, bool] = UNSET
    overtime_length: Union[Unset, float] = UNSET
    maximum_roster_size: Union[Unset, float] = UNSET
    period_break_duration: Union[Unset, float] = UNSET
    half_time_duration: Union[Unset, float] = UNSET
    maximum_players_on_court: Union[Unset, float] = UNSET
    maximum_goalkeeper_substitutions: Union[Unset, float] = UNSET
    type_of_cards: Union[Unset, list[MatchProfilesModelMatchProfileConfigurationTypeOfCardsItem]] = UNSET
    red_card_seconds: Union[Unset, float] = UNSET
    yellow_card_seconds: Union[Unset, float] = UNSET
    blue_card_seconds: Union[Unset, float] = UNSET
    match_roles: Union[Unset, list[MatchProfilesModelMatchProfileConfigurationMatchRolesItem]] = UNSET
    bib_numbers_required: Union[Unset, bool] = UNSET
    switch_playing_direction: Union[None, Unset, list[float]] = UNSET
    shootout_if_tie: Union[Unset, bool] = UNSET
    shots_until_sudden_death: Union[Unset, float] = UNSET
    timeouts_allowed: Union[Unset, float] = UNSET
    video_review_allowed: Union[Unset, bool] = UNSET
    reset_timeouts_after_periods: Union[None, Unset, list[float]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        number_of_periods = self.number_of_periods

        period_length = self.period_length

        overtime_allowed = self.overtime_allowed

        overtime_length = self.overtime_length

        maximum_roster_size = self.maximum_roster_size

        period_break_duration = self.period_break_duration

        half_time_duration = self.half_time_duration

        maximum_players_on_court = self.maximum_players_on_court

        maximum_goalkeeper_substitutions = self.maximum_goalkeeper_substitutions

        type_of_cards: Union[Unset, list[str]] = UNSET
        if not isinstance(self.type_of_cards, Unset):
            type_of_cards = []
            for type_of_cards_item_data in self.type_of_cards:
                type_of_cards_item = type_of_cards_item_data.value
                type_of_cards.append(type_of_cards_item)

        red_card_seconds = self.red_card_seconds

        yellow_card_seconds = self.yellow_card_seconds

        blue_card_seconds = self.blue_card_seconds

        match_roles: Union[Unset, list[str]] = UNSET
        if not isinstance(self.match_roles, Unset):
            match_roles = []
            for match_roles_item_data in self.match_roles:
                match_roles_item = match_roles_item_data.value
                match_roles.append(match_roles_item)

        bib_numbers_required = self.bib_numbers_required

        switch_playing_direction: Union[None, Unset, list[float]]
        if isinstance(self.switch_playing_direction, Unset):
            switch_playing_direction = UNSET
        elif isinstance(self.switch_playing_direction, list):
            switch_playing_direction = self.switch_playing_direction

        else:
            switch_playing_direction = self.switch_playing_direction

        shootout_if_tie = self.shootout_if_tie

        shots_until_sudden_death = self.shots_until_sudden_death

        timeouts_allowed = self.timeouts_allowed

        video_review_allowed = self.video_review_allowed

        reset_timeouts_after_periods: Union[None, Unset, list[float]]
        if isinstance(self.reset_timeouts_after_periods, Unset):
            reset_timeouts_after_periods = UNSET
        elif isinstance(self.reset_timeouts_after_periods, list):
            reset_timeouts_after_periods = self.reset_timeouts_after_periods

        else:
            reset_timeouts_after_periods = self.reset_timeouts_after_periods

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if number_of_periods is not UNSET:
            field_dict["numberOfPeriods"] = number_of_periods
        if period_length is not UNSET:
            field_dict["periodLength"] = period_length
        if overtime_allowed is not UNSET:
            field_dict["overtimeAllowed"] = overtime_allowed
        if overtime_length is not UNSET:
            field_dict["overtimeLength"] = overtime_length
        if maximum_roster_size is not UNSET:
            field_dict["maximumRosterSize"] = maximum_roster_size
        if period_break_duration is not UNSET:
            field_dict["periodBreakDuration"] = period_break_duration
        if half_time_duration is not UNSET:
            field_dict["halfTimeDuration"] = half_time_duration
        if maximum_players_on_court is not UNSET:
            field_dict["maximumPlayersOnCourt"] = maximum_players_on_court
        if maximum_goalkeeper_substitutions is not UNSET:
            field_dict["maximumGoalkeeperSubstitutions"] = maximum_goalkeeper_substitutions
        if type_of_cards is not UNSET:
            field_dict["typeOfCards"] = type_of_cards
        if red_card_seconds is not UNSET:
            field_dict["redCardSeconds"] = red_card_seconds
        if yellow_card_seconds is not UNSET:
            field_dict["yellowCardSeconds"] = yellow_card_seconds
        if blue_card_seconds is not UNSET:
            field_dict["blueCardSeconds"] = blue_card_seconds
        if match_roles is not UNSET:
            field_dict["matchRoles"] = match_roles
        if bib_numbers_required is not UNSET:
            field_dict["bibNumbersRequired"] = bib_numbers_required
        if switch_playing_direction is not UNSET:
            field_dict["switchPlayingDirection"] = switch_playing_direction
        if shootout_if_tie is not UNSET:
            field_dict["shootoutIfTie"] = shootout_if_tie
        if shots_until_sudden_death is not UNSET:
            field_dict["shotsUntilSuddenDeath"] = shots_until_sudden_death
        if timeouts_allowed is not UNSET:
            field_dict["timeoutsAllowed"] = timeouts_allowed
        if video_review_allowed is not UNSET:
            field_dict["videoReviewAllowed"] = video_review_allowed
        if reset_timeouts_after_periods is not UNSET:
            field_dict["resetTimeoutsAfterPeriods"] = reset_timeouts_after_periods

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        number_of_periods = d.pop("numberOfPeriods", UNSET)

        period_length = d.pop("periodLength", UNSET)

        overtime_allowed = d.pop("overtimeAllowed", UNSET)

        overtime_length = d.pop("overtimeLength", UNSET)

        maximum_roster_size = d.pop("maximumRosterSize", UNSET)

        period_break_duration = d.pop("periodBreakDuration", UNSET)

        half_time_duration = d.pop("halfTimeDuration", UNSET)

        maximum_players_on_court = d.pop("maximumPlayersOnCourt", UNSET)

        maximum_goalkeeper_substitutions = d.pop("maximumGoalkeeperSubstitutions", UNSET)

        type_of_cards = []
        _type_of_cards = d.pop("typeOfCards", UNSET)
        for type_of_cards_item_data in _type_of_cards or []:
            type_of_cards_item = MatchProfilesModelMatchProfileConfigurationTypeOfCardsItem(type_of_cards_item_data)

            type_of_cards.append(type_of_cards_item)

        red_card_seconds = d.pop("redCardSeconds", UNSET)

        yellow_card_seconds = d.pop("yellowCardSeconds", UNSET)

        blue_card_seconds = d.pop("blueCardSeconds", UNSET)

        match_roles = []
        _match_roles = d.pop("matchRoles", UNSET)
        for match_roles_item_data in _match_roles or []:
            match_roles_item = MatchProfilesModelMatchProfileConfigurationMatchRolesItem(match_roles_item_data)

            match_roles.append(match_roles_item)

        bib_numbers_required = d.pop("bibNumbersRequired", UNSET)

        def _parse_switch_playing_direction(data: object) -> Union[None, Unset, list[float]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                switch_playing_direction_type_0 = cast(list[float], data)

                return switch_playing_direction_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[float]], data)

        switch_playing_direction = _parse_switch_playing_direction(d.pop("switchPlayingDirection", UNSET))

        shootout_if_tie = d.pop("shootoutIfTie", UNSET)

        shots_until_sudden_death = d.pop("shotsUntilSuddenDeath", UNSET)

        timeouts_allowed = d.pop("timeoutsAllowed", UNSET)

        video_review_allowed = d.pop("videoReviewAllowed", UNSET)

        def _parse_reset_timeouts_after_periods(data: object) -> Union[None, Unset, list[float]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                reset_timeouts_after_periods_type_0 = cast(list[float], data)

                return reset_timeouts_after_periods_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[float]], data)

        reset_timeouts_after_periods = _parse_reset_timeouts_after_periods(d.pop("resetTimeoutsAfterPeriods", UNSET))

        match_profiles_model_match_profile_configuration = cls(
            number_of_periods=number_of_periods,
            period_length=period_length,
            overtime_allowed=overtime_allowed,
            overtime_length=overtime_length,
            maximum_roster_size=maximum_roster_size,
            period_break_duration=period_break_duration,
            half_time_duration=half_time_duration,
            maximum_players_on_court=maximum_players_on_court,
            maximum_goalkeeper_substitutions=maximum_goalkeeper_substitutions,
            type_of_cards=type_of_cards,
            red_card_seconds=red_card_seconds,
            yellow_card_seconds=yellow_card_seconds,
            blue_card_seconds=blue_card_seconds,
            match_roles=match_roles,
            bib_numbers_required=bib_numbers_required,
            switch_playing_direction=switch_playing_direction,
            shootout_if_tie=shootout_if_tie,
            shots_until_sudden_death=shots_until_sudden_death,
            timeouts_allowed=timeouts_allowed,
            video_review_allowed=video_review_allowed,
            reset_timeouts_after_periods=reset_timeouts_after_periods,
        )

        return match_profiles_model_match_profile_configuration



from enum import Enum


class TransferModelStatusType3Type1(str, Enum):
    APPROVED = "APPROVED"
    DECLINED = "DECLINED"
    PENDING = "PENDING"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.standing_configurations_model_standing_configuration_streak import (
    StandingConfigurationsModelStandingConfigurationStreak,
)
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.standing_configurations_model_standing_configuration_head_to_head_identification import (
        StandingConfigurationsModelStandingConfigurationHeadToHeadIdentification,
    )
    from ..models.standing_configurations_model_standing_configuration_head_to_head_identification_for_subsequent_checks import (
        StandingConfigurationsModelStandingConfigurationHeadToHeadIdentificationForSubsequentChecks,
    )
    from ..models.standing_configurations_model_standing_configuration_head_to_head_resolution import (
        StandingConfigurationsModelStandingConfigurationHeadToHeadResolution,
    )
    from ..models.standing_configurations_model_standing_configuration_head_to_head_resolution_for_extra_depth_h2_hs import (
        StandingConfigurationsModelStandingConfigurationHeadToHeadResolutionForExtraDepthH2Hs,
    )
    from ..models.standing_configurations_model_standing_configuration_sorting import (
        StandingConfigurationsModelStandingConfigurationSorting,
    )


T = TypeVar("T", bound="StandingConfigurationsModelStandingConfiguration")


@_attrs_define
class StandingConfigurationsModelStandingConfiguration:
    """Configuration definitions

    Attributes:
        losses_secondary_score_home_points (Union[Unset, float]): Points for Home Loss by Secondary Score
        losses_secondary_score_away_points (Union[Unset, float]): Points for Away Loss by Secondary Score
        wins_secondary_score_home_points (Union[Unset, float]): Points for Home Win by Secondary Score
        wins_secondary_score_away_points (Union[Unset, float]): Points for Away Win by Secondary Score
        wins_home_points (Union[Unset, float]): Points for Home Win
        losses_home_points (Union[Unset, float]): Points for Home Loss
        draws_home_scored_points (Union[Unset, float]): Points for Home Draw where team scored
        draws_home_zero_points (Union[Unset, float]): Points for Home Draw with zero score
        forfeit_won_by_home_points (Union[Unset, float]): Points for won by Forfeit at home
        forfeits_won_by_home_points (Union[Unset, float]): Points for won by Forfeit at home
        forfeit_given_home_points (Union[Unset, float]): Points for giving a forfeit at home
        wins_away_points (Union[Unset, float]): Points for Away Win
        losses_away_points (Union[Unset, float]): Points for Away Loss
        draws_away_scored_points (Union[Unset, float]): Points for Away Draw where team scored
        draws_away_zero_points (Union[Unset, float]): Points for Away Draw with zero score
        forfeit_won_by_away_points (Union[Unset, float]): Points for won by Forfeit at away
        forfeit_given_away_points (Union[Unset, float]): Points for giving a forfeit at away
        secondary_score_draw_as_result (Union[Unset, bool]): Is a secondary Score result a game result (resultPlace was
            a Draw)?
        check_secondary_scores (Union[Unset, bool]): Check Secondary Score for calculations
        bye_points (Union[Unset, float]): Points for bye
        bye_is_played (Union[Unset, bool]): Is a Bye added to played ?
        bye_added_wins (Union[Unset, bool]): Is a Bye added to won count?
        forfeit_won_by_added_wins (Union[Unset, bool]): Is a forfeit won by (received) included in won count ?
        forfeit_won_by_added_played (Union[Unset, bool]): Is a forfeit won by (received) included in played count ?
        forfeit_given_added_losses (Union[Unset, bool]): Is a forfeit given included in losses count ?
        forfeit_given_added_played (Union[Unset, bool]): Is a forfeit given included in played count ?
        streak (Union[Unset, StandingConfigurationsModelStandingConfigurationStreak]): How is a streak calculated ?
        sorts (Union[Unset, list['StandingConfigurationsModelStandingConfigurationSorting']]): Sortings
        head_to_head_identification (Union[Unset,
            list['StandingConfigurationsModelStandingConfigurationHeadToHeadIdentification']]): Head to head identifications
        head_to_head_identification_subsequent (Union[Unset,
            list['StandingConfigurationsModelStandingConfigurationHeadToHeadIdentificationForSubsequentChecks']]): Head to
            head identifications for subsequent checks
        head_to_head_use_all_fixtures (Union[Unset, bool]): Use all fixtures in Head to head resolutions regardless of
            Stage & Pool?
        head_to_head_use_adjustments (Union[Unset, bool]): Apply Standing Adjustments when performing Head to head
            resolutions?
        head_to_head_single_round (Union[Unset, bool]): Only use single round for Head to head resolutions?
        head_to_head_resolutions (Union[Unset,
            list['StandingConfigurationsModelStandingConfigurationHeadToHeadResolution']]): Head to head resolutions
        head_to_head_resolutions_subsequent (Union[Unset,
            list['StandingConfigurationsModelStandingConfigurationHeadToHeadResolutionForExtraDepthH2Hs']]): Head to head
            resolutions for extra depth h2h's
    """

    losses_secondary_score_home_points: Union[Unset, float] = UNSET
    losses_secondary_score_away_points: Union[Unset, float] = UNSET
    wins_secondary_score_home_points: Union[Unset, float] = UNSET
    wins_secondary_score_away_points: Union[Unset, float] = UNSET
    wins_home_points: Union[Unset, float] = UNSET
    losses_home_points: Union[Unset, float] = UNSET
    draws_home_scored_points: Union[Unset, float] = UNSET
    draws_home_zero_points: Union[Unset, float] = UNSET
    forfeit_won_by_home_points: Union[Unset, float] = UNSET
    forfeits_won_by_home_points: Union[Unset, float] = UNSET
    forfeit_given_home_points: Union[Unset, float] = UNSET
    wins_away_points: Union[Unset, float] = UNSET
    losses_away_points: Union[Unset, float] = UNSET
    draws_away_scored_points: Union[Unset, float] = UNSET
    draws_away_zero_points: Union[Unset, float] = UNSET
    forfeit_won_by_away_points: Union[Unset, float] = UNSET
    forfeit_given_away_points: Union[Unset, float] = UNSET
    secondary_score_draw_as_result: Union[Unset, bool] = UNSET
    check_secondary_scores: Union[Unset, bool] = UNSET
    bye_points: Union[Unset, float] = UNSET
    bye_is_played: Union[Unset, bool] = UNSET
    bye_added_wins: Union[Unset, bool] = UNSET
    forfeit_won_by_added_wins: Union[Unset, bool] = UNSET
    forfeit_won_by_added_played: Union[Unset, bool] = UNSET
    forfeit_given_added_losses: Union[Unset, bool] = UNSET
    forfeit_given_added_played: Union[Unset, bool] = UNSET
    streak: Union[Unset, StandingConfigurationsModelStandingConfigurationStreak] = UNSET
    sorts: Union[Unset, list["StandingConfigurationsModelStandingConfigurationSorting"]] = UNSET
    head_to_head_identification: Union[
        Unset, list["StandingConfigurationsModelStandingConfigurationHeadToHeadIdentification"]
    ] = UNSET
    head_to_head_identification_subsequent: Union[
        Unset, list["StandingConfigurationsModelStandingConfigurationHeadToHeadIdentificationForSubsequentChecks"]
    ] = UNSET
    head_to_head_use_all_fixtures: Union[Unset, bool] = UNSET
    head_to_head_use_adjustments: Union[Unset, bool] = UNSET
    head_to_head_single_round: Union[Unset, bool] = UNSET
    head_to_head_resolutions: Union[
        Unset, list["StandingConfigurationsModelStandingConfigurationHeadToHeadResolution"]
    ] = UNSET
    head_to_head_resolutions_subsequent: Union[
        Unset, list["StandingConfigurationsModelStandingConfigurationHeadToHeadResolutionForExtraDepthH2Hs"]
    ] = UNSET

    def to_dict(self) -> dict[str, Any]:
        losses_secondary_score_home_points = self.losses_secondary_score_home_points

        losses_secondary_score_away_points = self.losses_secondary_score_away_points

        wins_secondary_score_home_points = self.wins_secondary_score_home_points

        wins_secondary_score_away_points = self.wins_secondary_score_away_points

        wins_home_points = self.wins_home_points

        losses_home_points = self.losses_home_points

        draws_home_scored_points = self.draws_home_scored_points

        draws_home_zero_points = self.draws_home_zero_points

        forfeit_won_by_home_points = self.forfeit_won_by_home_points

        forfeits_won_by_home_points = self.forfeits_won_by_home_points

        forfeit_given_home_points = self.forfeit_given_home_points

        wins_away_points = self.wins_away_points

        losses_away_points = self.losses_away_points

        draws_away_scored_points = self.draws_away_scored_points

        draws_away_zero_points = self.draws_away_zero_points

        forfeit_won_by_away_points = self.forfeit_won_by_away_points

        forfeit_given_away_points = self.forfeit_given_away_points

        secondary_score_draw_as_result = self.secondary_score_draw_as_result

        check_secondary_scores = self.check_secondary_scores

        bye_points = self.bye_points

        bye_is_played = self.bye_is_played

        bye_added_wins = self.bye_added_wins

        forfeit_won_by_added_wins = self.forfeit_won_by_added_wins

        forfeit_won_by_added_played = self.forfeit_won_by_added_played

        forfeit_given_added_losses = self.forfeit_given_added_losses

        forfeit_given_added_played = self.forfeit_given_added_played

        streak: Union[Unset, str] = UNSET
        if not isinstance(self.streak, Unset):
            streak = self.streak.value

        sorts: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.sorts, Unset):
            sorts = []
            for sorts_item_data in self.sorts:
                sorts_item = sorts_item_data.to_dict()
                sorts.append(sorts_item)

        head_to_head_identification: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.head_to_head_identification, Unset):
            head_to_head_identification = []
            for head_to_head_identification_item_data in self.head_to_head_identification:
                head_to_head_identification_item = head_to_head_identification_item_data.to_dict()
                head_to_head_identification.append(head_to_head_identification_item)

        head_to_head_identification_subsequent: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.head_to_head_identification_subsequent, Unset):
            head_to_head_identification_subsequent = []
            for head_to_head_identification_subsequent_item_data in self.head_to_head_identification_subsequent:
                head_to_head_identification_subsequent_item = head_to_head_identification_subsequent_item_data.to_dict()
                head_to_head_identification_subsequent.append(head_to_head_identification_subsequent_item)

        head_to_head_use_all_fixtures = self.head_to_head_use_all_fixtures

        head_to_head_use_adjustments = self.head_to_head_use_adjustments

        head_to_head_single_round = self.head_to_head_single_round

        head_to_head_resolutions: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.head_to_head_resolutions, Unset):
            head_to_head_resolutions = []
            for head_to_head_resolutions_item_data in self.head_to_head_resolutions:
                head_to_head_resolutions_item = head_to_head_resolutions_item_data.to_dict()
                head_to_head_resolutions.append(head_to_head_resolutions_item)

        head_to_head_resolutions_subsequent: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.head_to_head_resolutions_subsequent, Unset):
            head_to_head_resolutions_subsequent = []
            for head_to_head_resolutions_subsequent_item_data in self.head_to_head_resolutions_subsequent:
                head_to_head_resolutions_subsequent_item = head_to_head_resolutions_subsequent_item_data.to_dict()
                head_to_head_resolutions_subsequent.append(head_to_head_resolutions_subsequent_item)

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if losses_secondary_score_home_points is not UNSET:
            field_dict["lossesSecondaryScoreHomePoints"] = losses_secondary_score_home_points
        if losses_secondary_score_away_points is not UNSET:
            field_dict["lossesSecondaryScoreAwayPoints"] = losses_secondary_score_away_points
        if wins_secondary_score_home_points is not UNSET:
            field_dict["winsSecondaryScoreHomePoints"] = wins_secondary_score_home_points
        if wins_secondary_score_away_points is not UNSET:
            field_dict["winsSecondaryScoreAwayPoints"] = wins_secondary_score_away_points
        if wins_home_points is not UNSET:
            field_dict["winsHomePoints"] = wins_home_points
        if losses_home_points is not UNSET:
            field_dict["lossesHomePoints"] = losses_home_points
        if draws_home_scored_points is not UNSET:
            field_dict["drawsHomeScoredPoints"] = draws_home_scored_points
        if draws_home_zero_points is not UNSET:
            field_dict["drawsHomeZeroPoints"] = draws_home_zero_points
        if forfeit_won_by_home_points is not UNSET:
            field_dict["forfeitWonByHomePoints"] = forfeit_won_by_home_points
        if forfeits_won_by_home_points is not UNSET:
            field_dict["forfeitsWonByHomePoints"] = forfeits_won_by_home_points
        if forfeit_given_home_points is not UNSET:
            field_dict["forfeitGivenHomePoints"] = forfeit_given_home_points
        if wins_away_points is not UNSET:
            field_dict["winsAwayPoints"] = wins_away_points
        if losses_away_points is not UNSET:
            field_dict["lossesAwayPoints"] = losses_away_points
        if draws_away_scored_points is not UNSET:
            field_dict["drawsAwayScoredPoints"] = draws_away_scored_points
        if draws_away_zero_points is not UNSET:
            field_dict["drawsAwayZeroPoints"] = draws_away_zero_points
        if forfeit_won_by_away_points is not UNSET:
            field_dict["forfeitWonByAwayPoints"] = forfeit_won_by_away_points
        if forfeit_given_away_points is not UNSET:
            field_dict["forfeitGivenAwayPoints"] = forfeit_given_away_points
        if secondary_score_draw_as_result is not UNSET:
            field_dict["secondaryScoreDrawAsResult"] = secondary_score_draw_as_result
        if check_secondary_scores is not UNSET:
            field_dict["checkSecondaryScores"] = check_secondary_scores
        if bye_points is not UNSET:
            field_dict["byePoints"] = bye_points
        if bye_is_played is not UNSET:
            field_dict["byeIsPlayed"] = bye_is_played
        if bye_added_wins is not UNSET:
            field_dict["byeAddedWins"] = bye_added_wins
        if forfeit_won_by_added_wins is not UNSET:
            field_dict["forfeitWonByAddedWins"] = forfeit_won_by_added_wins
        if forfeit_won_by_added_played is not UNSET:
            field_dict["forfeitWonByAddedPlayed"] = forfeit_won_by_added_played
        if forfeit_given_added_losses is not UNSET:
            field_dict["forfeitGivenAddedLosses"] = forfeit_given_added_losses
        if forfeit_given_added_played is not UNSET:
            field_dict["forfeitGivenAddedPlayed"] = forfeit_given_added_played
        if streak is not UNSET:
            field_dict["streak"] = streak
        if sorts is not UNSET:
            field_dict["sorts"] = sorts
        if head_to_head_identification is not UNSET:
            field_dict["headToHeadIdentification"] = head_to_head_identification
        if head_to_head_identification_subsequent is not UNSET:
            field_dict["headToHeadIdentificationSubsequent"] = head_to_head_identification_subsequent
        if head_to_head_use_all_fixtures is not UNSET:
            field_dict["headToHeadUseAllFixtures"] = head_to_head_use_all_fixtures
        if head_to_head_use_adjustments is not UNSET:
            field_dict["headToHeadUseAdjustments"] = head_to_head_use_adjustments
        if head_to_head_single_round is not UNSET:
            field_dict["headToHeadSingleRound"] = head_to_head_single_round
        if head_to_head_resolutions is not UNSET:
            field_dict["headToHeadResolutions"] = head_to_head_resolutions
        if head_to_head_resolutions_subsequent is not UNSET:
            field_dict["headToHeadResolutionsSubsequent"] = head_to_head_resolutions_subsequent

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.standing_configurations_model_standing_configuration_head_to_head_identification import (
            StandingConfigurationsModelStandingConfigurationHeadToHeadIdentification,
        )
        from ..models.standing_configurations_model_standing_configuration_head_to_head_identification_for_subsequent_checks import (
            StandingConfigurationsModelStandingConfigurationHeadToHeadIdentificationForSubsequentChecks,
        )
        from ..models.standing_configurations_model_standing_configuration_head_to_head_resolution import (
            StandingConfigurationsModelStandingConfigurationHeadToHeadResolution,
        )
        from ..models.standing_configurations_model_standing_configuration_head_to_head_resolution_for_extra_depth_h2_hs import (
            StandingConfigurationsModelStandingConfigurationHeadToHeadResolutionForExtraDepthH2Hs,
        )
        from ..models.standing_configurations_model_standing_configuration_sorting import (
            StandingConfigurationsModelStandingConfigurationSorting,
        )

        d = dict(src_dict)
        losses_secondary_score_home_points = d.pop("lossesSecondaryScoreHomePoints", UNSET)

        losses_secondary_score_away_points = d.pop("lossesSecondaryScoreAwayPoints", UNSET)

        wins_secondary_score_home_points = d.pop("winsSecondaryScoreHomePoints", UNSET)

        wins_secondary_score_away_points = d.pop("winsSecondaryScoreAwayPoints", UNSET)

        wins_home_points = d.pop("winsHomePoints", UNSET)

        losses_home_points = d.pop("lossesHomePoints", UNSET)

        draws_home_scored_points = d.pop("drawsHomeScoredPoints", UNSET)

        draws_home_zero_points = d.pop("drawsHomeZeroPoints", UNSET)

        forfeit_won_by_home_points = d.pop("forfeitWonByHomePoints", UNSET)

        forfeits_won_by_home_points = d.pop("forfeitsWonByHomePoints", UNSET)

        forfeit_given_home_points = d.pop("forfeitGivenHomePoints", UNSET)

        wins_away_points = d.pop("winsAwayPoints", UNSET)

        losses_away_points = d.pop("lossesAwayPoints", UNSET)

        draws_away_scored_points = d.pop("drawsAwayScoredPoints", UNSET)

        draws_away_zero_points = d.pop("drawsAwayZeroPoints", UNSET)

        forfeit_won_by_away_points = d.pop("forfeitWonByAwayPoints", UNSET)

        forfeit_given_away_points = d.pop("forfeitGivenAwayPoints", UNSET)

        secondary_score_draw_as_result = d.pop("secondaryScoreDrawAsResult", UNSET)

        check_secondary_scores = d.pop("checkSecondaryScores", UNSET)

        bye_points = d.pop("byePoints", UNSET)

        bye_is_played = d.pop("byeIsPlayed", UNSET)

        bye_added_wins = d.pop("byeAddedWins", UNSET)

        forfeit_won_by_added_wins = d.pop("forfeitWonByAddedWins", UNSET)

        forfeit_won_by_added_played = d.pop("forfeitWonByAddedPlayed", UNSET)

        forfeit_given_added_losses = d.pop("forfeitGivenAddedLosses", UNSET)

        forfeit_given_added_played = d.pop("forfeitGivenAddedPlayed", UNSET)

        _streak = d.pop("streak", UNSET)
        streak: Union[Unset, StandingConfigurationsModelStandingConfigurationStreak]
        if isinstance(_streak, Unset):
            streak = UNSET
        else:
            streak = StandingConfigurationsModelStandingConfigurationStreak(_streak)

        sorts = []
        _sorts = d.pop("sorts", UNSET)
        for sorts_item_data in _sorts or []:
            sorts_item = StandingConfigurationsModelStandingConfigurationSorting.from_dict(sorts_item_data)

            sorts.append(sorts_item)

        head_to_head_identification = []
        _head_to_head_identification = d.pop("headToHeadIdentification", UNSET)
        for head_to_head_identification_item_data in _head_to_head_identification or []:
            head_to_head_identification_item = (
                StandingConfigurationsModelStandingConfigurationHeadToHeadIdentification.from_dict(
                    head_to_head_identification_item_data
                )
            )

            head_to_head_identification.append(head_to_head_identification_item)

        head_to_head_identification_subsequent = []
        _head_to_head_identification_subsequent = d.pop("headToHeadIdentificationSubsequent", UNSET)
        for head_to_head_identification_subsequent_item_data in _head_to_head_identification_subsequent or []:
            head_to_head_identification_subsequent_item = (
                StandingConfigurationsModelStandingConfigurationHeadToHeadIdentificationForSubsequentChecks.from_dict(
                    head_to_head_identification_subsequent_item_data
                )
            )

            head_to_head_identification_subsequent.append(head_to_head_identification_subsequent_item)

        head_to_head_use_all_fixtures = d.pop("headToHeadUseAllFixtures", UNSET)

        head_to_head_use_adjustments = d.pop("headToHeadUseAdjustments", UNSET)

        head_to_head_single_round = d.pop("headToHeadSingleRound", UNSET)

        head_to_head_resolutions = []
        _head_to_head_resolutions = d.pop("headToHeadResolutions", UNSET)
        for head_to_head_resolutions_item_data in _head_to_head_resolutions or []:
            head_to_head_resolutions_item = (
                StandingConfigurationsModelStandingConfigurationHeadToHeadResolution.from_dict(
                    head_to_head_resolutions_item_data
                )
            )

            head_to_head_resolutions.append(head_to_head_resolutions_item)

        head_to_head_resolutions_subsequent = []
        _head_to_head_resolutions_subsequent = d.pop("headToHeadResolutionsSubsequent", UNSET)
        for head_to_head_resolutions_subsequent_item_data in _head_to_head_resolutions_subsequent or []:
            head_to_head_resolutions_subsequent_item = (
                StandingConfigurationsModelStandingConfigurationHeadToHeadResolutionForExtraDepthH2Hs.from_dict(
                    head_to_head_resolutions_subsequent_item_data
                )
            )

            head_to_head_resolutions_subsequent.append(head_to_head_resolutions_subsequent_item)

        standing_configurations_model_standing_configuration = cls(
            losses_secondary_score_home_points=losses_secondary_score_home_points,
            losses_secondary_score_away_points=losses_secondary_score_away_points,
            wins_secondary_score_home_points=wins_secondary_score_home_points,
            wins_secondary_score_away_points=wins_secondary_score_away_points,
            wins_home_points=wins_home_points,
            losses_home_points=losses_home_points,
            draws_home_scored_points=draws_home_scored_points,
            draws_home_zero_points=draws_home_zero_points,
            forfeit_won_by_home_points=forfeit_won_by_home_points,
            forfeits_won_by_home_points=forfeits_won_by_home_points,
            forfeit_given_home_points=forfeit_given_home_points,
            wins_away_points=wins_away_points,
            losses_away_points=losses_away_points,
            draws_away_scored_points=draws_away_scored_points,
            draws_away_zero_points=draws_away_zero_points,
            forfeit_won_by_away_points=forfeit_won_by_away_points,
            forfeit_given_away_points=forfeit_given_away_points,
            secondary_score_draw_as_result=secondary_score_draw_as_result,
            check_secondary_scores=check_secondary_scores,
            bye_points=bye_points,
            bye_is_played=bye_is_played,
            bye_added_wins=bye_added_wins,
            forfeit_won_by_added_wins=forfeit_won_by_added_wins,
            forfeit_won_by_added_played=forfeit_won_by_added_played,
            forfeit_given_added_losses=forfeit_given_added_losses,
            forfeit_given_added_played=forfeit_given_added_played,
            streak=streak,
            sorts=sorts,
            head_to_head_identification=head_to_head_identification,
            head_to_head_identification_subsequent=head_to_head_identification_subsequent,
            head_to_head_use_all_fixtures=head_to_head_use_all_fixtures,
            head_to_head_use_adjustments=head_to_head_use_adjustments,
            head_to_head_single_round=head_to_head_single_round,
            head_to_head_resolutions=head_to_head_resolutions,
            head_to_head_resolutions_subsequent=head_to_head_resolutions_subsequent,
        )

        return standing_configurations_model_standing_configuration



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.league_external_ids_model_league import LeagueExternalIdsModelLeague
    from ..models.league_external_ids_model_organization import LeagueExternalIdsModelOrganization


T = TypeVar("T", bound="LeagueExternalIdsModel")


@_attrs_define
class LeagueExternalIdsModel:
    """
    Attributes:
        league_external_id (Union[Unset, UUID]): The unique identifier of the external ids Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, LeagueExternalIdsModelOrganization]): The organization that this league external ids
            belongs to
        league_id (Union[Unset, UUID]): The unique identifier of the league Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        league (Union[Unset, LeagueExternalIdsModelLeague]): The league that this league external ids belongs to
        source (Union[Unset, str]): The source of the external Id Example: urn:sources:sportradar.com.
        source_type (Union[Unset, str]): Source type of external Id
        source_external_id (Union[Unset, str]): Identifier of external source Example: SR:123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    league_external_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "LeagueExternalIdsModelOrganization"] = UNSET
    league_id: Union[Unset, UUID] = UNSET
    league: Union[Unset, "LeagueExternalIdsModelLeague"] = UNSET
    source: Union[Unset, str] = UNSET
    source_type: Union[Unset, str] = UNSET
    source_external_id: Union[Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        league_external_id: Union[Unset, str] = UNSET
        if not isinstance(self.league_external_id, Unset):
            league_external_id = str(self.league_external_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        league_id: Union[Unset, str] = UNSET
        if not isinstance(self.league_id, Unset):
            league_id = str(self.league_id)

        league: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.league, Unset):
            league = self.league.to_dict()

        source = self.source

        source_type = self.source_type

        source_external_id = self.source_external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if league_external_id is not UNSET:
            field_dict["leagueExternalId"] = league_external_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if league_id is not UNSET:
            field_dict["leagueId"] = league_id
        if league is not UNSET:
            field_dict["league"] = league
        if source is not UNSET:
            field_dict["source"] = source
        if source_type is not UNSET:
            field_dict["sourceType"] = source_type
        if source_external_id is not UNSET:
            field_dict["sourceExternalId"] = source_external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.league_external_ids_model_league import LeagueExternalIdsModelLeague
        from ..models.league_external_ids_model_organization import LeagueExternalIdsModelOrganization

        d = dict(src_dict)
        _league_external_id = d.pop("leagueExternalId", UNSET)
        league_external_id: Union[Unset, UUID]
        if isinstance(_league_external_id, Unset):
            league_external_id = UNSET
        else:
            league_external_id = UUID(_league_external_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, LeagueExternalIdsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = LeagueExternalIdsModelOrganization.from_dict(_organization)

        _league_id = d.pop("leagueId", UNSET)
        league_id: Union[Unset, UUID]
        if isinstance(_league_id, Unset):
            league_id = UNSET
        else:
            league_id = UUID(_league_id)

        _league = d.pop("league", UNSET)
        league: Union[Unset, LeagueExternalIdsModelLeague]
        if isinstance(_league, Unset):
            league = UNSET
        else:
            league = LeagueExternalIdsModelLeague.from_dict(_league)

        source = d.pop("source", UNSET)

        source_type = d.pop("sourceType", UNSET)

        source_external_id = d.pop("sourceExternalId", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        league_external_ids_model = cls(
            league_external_id=league_external_id,
            organization_id=organization_id,
            organization=organization,
            league_id=league_id,
            league=league,
            source=source,
            source_type=source_type,
            source_external_id=source_external_id,
            updated=updated,
            added=added,
        )

        return league_external_ids_model



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.season_person_statistics_model import SeasonPersonStatisticsModel


T = TypeVar("T", bound="SeasonLeaderSummaryModel")


@_attrs_define
class SeasonLeaderSummaryModel:
    """
    Attributes:
        stat_name (Union[Unset, list['SeasonPersonStatisticsModel']]): There will be an element/object here for each
            statistic you have requested. The 'statName' key will be the name of the statistics. eg `points`
    """

    stat_name: Union[Unset, list["SeasonPersonStatisticsModel"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        stat_name: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.stat_name, Unset):
            stat_name = []
            for stat_name_item_data in self.stat_name:
                stat_name_item = stat_name_item_data.to_dict()
                stat_name.append(stat_name_item)

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if stat_name is not UNSET:
            field_dict["statName"] = stat_name

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.season_person_statistics_model import SeasonPersonStatisticsModel

        d = dict(src_dict)
        stat_name = []
        _stat_name = d.pop("statName", UNSET)
        for stat_name_item_data in _stat_name or []:
            stat_name_item = SeasonPersonStatisticsModel.from_dict(stat_name_item_data)

            stat_name.append(stat_name_item)

        season_leader_summary_model = cls(
            stat_name=stat_name,
        )

        return season_leader_summary_model



from enum import Enum


class EntityListByEntityGroupGender(str, Enum):
    FEMALE = "FEMALE"
    MALE = "MALE"
    MIXED = "MIXED"
    UNKNOWN = "UNKNOWN"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.conference_external_ids_model_conference import ConferenceExternalIdsModelConference
    from ..models.conference_external_ids_model_organization import ConferenceExternalIdsModelOrganization


T = TypeVar("T", bound="ConferenceExternalIdsModel")


@_attrs_define
class ConferenceExternalIdsModel:
    """
    Attributes:
        conference_external_id (Union[Unset, UUID]): The unique identifier of the external ids Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, ConferenceExternalIdsModelOrganization]): The organization that this conference
            external ids belongs to
        conference_id (Union[None, UUID, Unset]): The unique identifier of the conference Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        conference (Union[Unset, ConferenceExternalIdsModelConference]): The conference information
        source (Union[Unset, str]): The source of the external Id Example: urn:sources:sportradar.com.
        source_type (Union[Unset, str]): Source type of external Id
        source_external_id (Union[Unset, str]): Identifier of external source Example: SR:123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    conference_external_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "ConferenceExternalIdsModelOrganization"] = UNSET
    conference_id: Union[None, UUID, Unset] = UNSET
    conference: Union[Unset, "ConferenceExternalIdsModelConference"] = UNSET
    source: Union[Unset, str] = UNSET
    source_type: Union[Unset, str] = UNSET
    source_external_id: Union[Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        conference_external_id: Union[Unset, str] = UNSET
        if not isinstance(self.conference_external_id, Unset):
            conference_external_id = str(self.conference_external_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        conference_id: Union[None, Unset, str]
        if isinstance(self.conference_id, Unset):
            conference_id = UNSET
        elif isinstance(self.conference_id, UUID):
            conference_id = str(self.conference_id)
        else:
            conference_id = self.conference_id

        conference: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.conference, Unset):
            conference = self.conference.to_dict()

        source = self.source

        source_type = self.source_type

        source_external_id = self.source_external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if conference_external_id is not UNSET:
            field_dict["conferenceExternalId"] = conference_external_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if conference_id is not UNSET:
            field_dict["conferenceId"] = conference_id
        if conference is not UNSET:
            field_dict["conference"] = conference
        if source is not UNSET:
            field_dict["source"] = source
        if source_type is not UNSET:
            field_dict["sourceType"] = source_type
        if source_external_id is not UNSET:
            field_dict["sourceExternalId"] = source_external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.conference_external_ids_model_conference import ConferenceExternalIdsModelConference
        from ..models.conference_external_ids_model_organization import ConferenceExternalIdsModelOrganization

        d = dict(src_dict)
        _conference_external_id = d.pop("conferenceExternalId", UNSET)
        conference_external_id: Union[Unset, UUID]
        if isinstance(_conference_external_id, Unset):
            conference_external_id = UNSET
        else:
            conference_external_id = UUID(_conference_external_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, ConferenceExternalIdsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = ConferenceExternalIdsModelOrganization.from_dict(_organization)

        def _parse_conference_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                conference_id_type_0 = UUID(data)

                return conference_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        conference_id = _parse_conference_id(d.pop("conferenceId", UNSET))

        _conference = d.pop("conference", UNSET)
        conference: Union[Unset, ConferenceExternalIdsModelConference]
        if isinstance(_conference, Unset):
            conference = UNSET
        else:
            conference = ConferenceExternalIdsModelConference.from_dict(_conference)

        source = d.pop("source", UNSET)

        source_type = d.pop("sourceType", UNSET)

        source_external_id = d.pop("sourceExternalId", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        conference_external_ids_model = cls(
            conference_external_id=conference_external_id,
            organization_id=organization_id,
            organization=organization,
            conference_id=conference_id,
            conference=conference,
            source=source,
            source_type=source_type,
            source_external_id=source_external_id,
            updated=updated,
            added=added,
        )

        return conference_external_ids_model



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="StandingConfigurationsModelStandingConfigurationHeadToHeadIdentification")


@_attrs_define
class StandingConfigurationsModelStandingConfigurationHeadToHeadIdentification:
    """
    Attributes:
        check_field (Union[Unset, str]): Field to check
    """

    check_field: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        check_field = self.check_field

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if check_field is not UNSET:
            field_dict["checkField"] = check_field

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        check_field = d.pop("checkField", UNSET)

        standing_configurations_model_standing_configuration_head_to_head_identification = cls(
            check_field=check_field,
        )

        return standing_configurations_model_standing_configuration_head_to_head_identification



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.competition_person_statistics_model_competition import CompetitionPersonStatisticsModelCompetition
    from ..models.competition_person_statistics_model_organization import CompetitionPersonStatisticsModelOrganization
    from ..models.competition_person_statistics_model_person import CompetitionPersonStatisticsModelPerson
    from ..models.competition_person_statistics_model_statistics import CompetitionPersonStatisticsModelStatistics


T = TypeVar("T", bound="CompetitionPersonStatisticsModel")


@_attrs_define
class CompetitionPersonStatisticsModel:
    """
    Attributes:
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, CompetitionPersonStatisticsModelPerson]): The person information
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, CompetitionPersonStatisticsModelOrganization]): The organization that this
            competition person statistics belongs to
        competition_id (Union[Unset, UUID]): The unique identifier of the competition Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        competition (Union[Unset, CompetitionPersonStatisticsModelCompetition]): The competition that this season
            belongs to
        statistics (Union[Unset, CompetitionPersonStatisticsModelStatistics]):
    """

    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "CompetitionPersonStatisticsModelPerson"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "CompetitionPersonStatisticsModelOrganization"] = UNSET
    competition_id: Union[Unset, UUID] = UNSET
    competition: Union[Unset, "CompetitionPersonStatisticsModelCompetition"] = UNSET
    statistics: Union[Unset, "CompetitionPersonStatisticsModelStatistics"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        competition_id: Union[Unset, str] = UNSET
        if not isinstance(self.competition_id, Unset):
            competition_id = str(self.competition_id)

        competition: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.competition, Unset):
            competition = self.competition.to_dict()

        statistics: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.statistics, Unset):
            statistics = self.statistics.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if competition_id is not UNSET:
            field_dict["competitionId"] = competition_id
        if competition is not UNSET:
            field_dict["competition"] = competition
        if statistics is not UNSET:
            field_dict["statistics"] = statistics

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.competition_person_statistics_model_competition import CompetitionPersonStatisticsModelCompetition
        from ..models.competition_person_statistics_model_organization import (
            CompetitionPersonStatisticsModelOrganization,
        )
        from ..models.competition_person_statistics_model_person import CompetitionPersonStatisticsModelPerson
        from ..models.competition_person_statistics_model_statistics import CompetitionPersonStatisticsModelStatistics

        d = dict(src_dict)
        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, CompetitionPersonStatisticsModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = CompetitionPersonStatisticsModelPerson.from_dict(_person)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, CompetitionPersonStatisticsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = CompetitionPersonStatisticsModelOrganization.from_dict(_organization)

        _competition_id = d.pop("competitionId", UNSET)
        competition_id: Union[Unset, UUID]
        if isinstance(_competition_id, Unset):
            competition_id = UNSET
        else:
            competition_id = UUID(_competition_id)

        _competition = d.pop("competition", UNSET)
        competition: Union[Unset, CompetitionPersonStatisticsModelCompetition]
        if isinstance(_competition, Unset):
            competition = UNSET
        else:
            competition = CompetitionPersonStatisticsModelCompetition.from_dict(_competition)

        _statistics = d.pop("statistics", UNSET)
        statistics: Union[Unset, CompetitionPersonStatisticsModelStatistics]
        if isinstance(_statistics, Unset):
            statistics = UNSET
        else:
            statistics = CompetitionPersonStatisticsModelStatistics.from_dict(_statistics)

        competition_person_statistics_model = cls(
            person_id=person_id,
            person=person,
            organization_id=organization_id,
            organization=organization,
            competition_id=competition_id,
            competition=competition,
            statistics=statistics,
        )

        return competition_person_statistics_model



from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ...client import AuthenticatedClient, Client
from ...models.sl_list_summary_fixture_type import SlListSummaryFixtureType
from ...models.sl_list_summary_home_away import SlListSummaryHomeAway
from ...models.sl_list_summary_leader_summary_response import SlListSummaryLeaderSummaryResponse
from ...models.sl_list_summary_response_default import SlListSummaryResponseDefault
from ...models.sl_list_summary_win_loss import SlListSummaryWinLoss
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_id: str,
    season_id: UUID,
    *,
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, SlListSummaryFixtureType] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    home_away: Union[Unset, SlListSummaryHomeAway] = UNSET,
    include: Union[Unset, str] = UNSET,
    is_player: Union[Unset, bool] = UNSET,
    is_team_official: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    starter: Union[Unset, bool] = UNSET,
    statistics: Union[Unset, str] = UNSET,
    win_loss: Union[Unset, SlListSummaryWinLoss] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_entity_id: Union[Unset, str] = UNSET
    if not isinstance(entity_id, Unset):
        json_entity_id = str(entity_id)
    params["entityId"] = json_entity_id

    params["external"] = external

    params["fields"] = fields

    json_fixture_type: Union[Unset, str] = UNSET
    if not isinstance(fixture_type, Unset):
        json_fixture_type = fixture_type.value

    params["fixtureType"] = json_fixture_type

    params["hideNull"] = hide_null

    json_home_away: Union[Unset, str] = UNSET
    if not isinstance(home_away, Unset):
        json_home_away = home_away.value

    params["homeAway"] = json_home_away

    params["include"] = include

    params["isPlayer"] = is_player

    params["isTeamOfficial"] = is_team_official

    params["limit"] = limit

    params["offset"] = offset

    json_person_id: Union[Unset, str] = UNSET
    if not isinstance(person_id, Unset):
        json_person_id = str(person_id)
    params["personId"] = json_person_id

    params["starter"] = starter

    params["statistics"] = statistics

    json_win_loss: Union[Unset, str] = UNSET
    if not isinstance(win_loss, Unset):
        json_win_loss = win_loss.value

    params["winLoss"] = json_win_loss

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/handball/o/{organization_id}/statistics/leaders/in/seasons/{season_id}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Union[SlListSummaryLeaderSummaryResponse, SlListSummaryResponseDefault]:
    if response.status_code == 200:
        response_200 = SlListSummaryLeaderSummaryResponse.from_dict(response.json())

        return response_200

    response_default = SlListSummaryResponseDefault.from_dict(response.json())

    return response_default


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[SlListSummaryLeaderSummaryResponse, SlListSummaryResponseDefault]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    organization_id: str,
    season_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, SlListSummaryFixtureType] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    home_away: Union[Unset, SlListSummaryHomeAway] = UNSET,
    include: Union[Unset, str] = UNSET,
    is_player: Union[Unset, bool] = UNSET,
    is_team_official: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    starter: Union[Unset, bool] = UNSET,
    statistics: Union[Unset, str] = UNSET,
    win_loss: Union[Unset, SlListSummaryWinLoss] = UNSET,
) -> Response[Union[SlListSummaryLeaderSummaryResponse, SlListSummaryResponseDefault]]:
    """Season statistical leader summary

     Return a summary of the leading persons for a number of statistics in a season.

    This call allows you to specify multiple statistics at the same time.  It will return objects for
    each statistic.  In the 'statistics' object only the requested statistic will be returned, not all
    available statistics.

    This call also applies the qualification criteria (defined in the leaders qualification api calls)
    to each person.

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, SlListSummaryFixtureType]):  Example: REGULAR.
        hide_null (Union[Unset, bool]):  Example: True.
        home_away (Union[Unset, SlListSummaryHomeAway]):
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        is_player (Union[Unset, bool]):
        is_team_official (Union[Unset, bool]):
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        person_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        starter (Union[Unset, bool]):
        statistics (Union[Unset, str]):  Example: points,minutes.
        win_loss (Union[Unset, SlListSummaryWinLoss]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[SlListSummaryLeaderSummaryResponse, SlListSummaryResponseDefault]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        season_id=season_id,
        entity_id=entity_id,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        hide_null=hide_null,
        home_away=home_away,
        include=include,
        is_player=is_player,
        is_team_official=is_team_official,
        limit=limit,
        offset=offset,
        person_id=person_id,
        starter=starter,
        statistics=statistics,
        win_loss=win_loss,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    organization_id: str,
    season_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, SlListSummaryFixtureType] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    home_away: Union[Unset, SlListSummaryHomeAway] = UNSET,
    include: Union[Unset, str] = UNSET,
    is_player: Union[Unset, bool] = UNSET,
    is_team_official: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    starter: Union[Unset, bool] = UNSET,
    statistics: Union[Unset, str] = UNSET,
    win_loss: Union[Unset, SlListSummaryWinLoss] = UNSET,
) -> Optional[Union[SlListSummaryLeaderSummaryResponse, SlListSummaryResponseDefault]]:
    """Season statistical leader summary

     Return a summary of the leading persons for a number of statistics in a season.

    This call allows you to specify multiple statistics at the same time.  It will return objects for
    each statistic.  In the 'statistics' object only the requested statistic will be returned, not all
    available statistics.

    This call also applies the qualification criteria (defined in the leaders qualification api calls)
    to each person.

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, SlListSummaryFixtureType]):  Example: REGULAR.
        hide_null (Union[Unset, bool]):  Example: True.
        home_away (Union[Unset, SlListSummaryHomeAway]):
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        is_player (Union[Unset, bool]):
        is_team_official (Union[Unset, bool]):
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        person_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        starter (Union[Unset, bool]):
        statistics (Union[Unset, str]):  Example: points,minutes.
        win_loss (Union[Unset, SlListSummaryWinLoss]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[SlListSummaryLeaderSummaryResponse, SlListSummaryResponseDefault]
    """

    return sync_detailed(
        organization_id=organization_id,
        season_id=season_id,
        client=client,
        entity_id=entity_id,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        hide_null=hide_null,
        home_away=home_away,
        include=include,
        is_player=is_player,
        is_team_official=is_team_official,
        limit=limit,
        offset=offset,
        person_id=person_id,
        starter=starter,
        statistics=statistics,
        win_loss=win_loss,
    ).parsed


async def asyncio_detailed(
    organization_id: str,
    season_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, SlListSummaryFixtureType] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    home_away: Union[Unset, SlListSummaryHomeAway] = UNSET,
    include: Union[Unset, str] = UNSET,
    is_player: Union[Unset, bool] = UNSET,
    is_team_official: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    starter: Union[Unset, bool] = UNSET,
    statistics: Union[Unset, str] = UNSET,
    win_loss: Union[Unset, SlListSummaryWinLoss] = UNSET,
) -> Response[Union[SlListSummaryLeaderSummaryResponse, SlListSummaryResponseDefault]]:
    """Season statistical leader summary

     Return a summary of the leading persons for a number of statistics in a season.

    This call allows you to specify multiple statistics at the same time.  It will return objects for
    each statistic.  In the 'statistics' object only the requested statistic will be returned, not all
    available statistics.

    This call also applies the qualification criteria (defined in the leaders qualification api calls)
    to each person.

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, SlListSummaryFixtureType]):  Example: REGULAR.
        hide_null (Union[Unset, bool]):  Example: True.
        home_away (Union[Unset, SlListSummaryHomeAway]):
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        is_player (Union[Unset, bool]):
        is_team_official (Union[Unset, bool]):
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        person_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        starter (Union[Unset, bool]):
        statistics (Union[Unset, str]):  Example: points,minutes.
        win_loss (Union[Unset, SlListSummaryWinLoss]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[SlListSummaryLeaderSummaryResponse, SlListSummaryResponseDefault]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        season_id=season_id,
        entity_id=entity_id,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        hide_null=hide_null,
        home_away=home_away,
        include=include,
        is_player=is_player,
        is_team_official=is_team_official,
        limit=limit,
        offset=offset,
        person_id=person_id,
        starter=starter,
        statistics=statistics,
        win_loss=win_loss,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    organization_id: str,
    season_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, SlListSummaryFixtureType] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    home_away: Union[Unset, SlListSummaryHomeAway] = UNSET,
    include: Union[Unset, str] = UNSET,
    is_player: Union[Unset, bool] = UNSET,
    is_team_official: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    starter: Union[Unset, bool] = UNSET,
    statistics: Union[Unset, str] = UNSET,
    win_loss: Union[Unset, SlListSummaryWinLoss] = UNSET,
) -> Optional[Union[SlListSummaryLeaderSummaryResponse, SlListSummaryResponseDefault]]:
    """Season statistical leader summary

     Return a summary of the leading persons for a number of statistics in a season.

    This call allows you to specify multiple statistics at the same time.  It will return objects for
    each statistic.  In the 'statistics' object only the requested statistic will be returned, not all
    available statistics.

    This call also applies the qualification criteria (defined in the leaders qualification api calls)
    to each person.

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, SlListSummaryFixtureType]):  Example: REGULAR.
        hide_null (Union[Unset, bool]):  Example: True.
        home_away (Union[Unset, SlListSummaryHomeAway]):
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        is_player (Union[Unset, bool]):
        is_team_official (Union[Unset, bool]):
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        person_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        starter (Union[Unset, bool]):
        statistics (Union[Unset, str]):  Example: points,minutes.
        win_loss (Union[Unset, SlListSummaryWinLoss]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[SlListSummaryLeaderSummaryResponse, SlListSummaryResponseDefault]
    """

    return (
        await asyncio_detailed(
            organization_id=organization_id,
            season_id=season_id,
            client=client,
            entity_id=entity_id,
            external=external,
            fields=fields,
            fixture_type=fixture_type,
            hide_null=hide_null,
            home_away=home_away,
            include=include,
            is_player=is_player,
            is_team_official=is_team_official,
            limit=limit,
            offset=offset,
            person_id=person_id,
            starter=starter,
            statistics=statistics,
            win_loss=win_loss,
        )
    ).parsed
